<?php

declare(strict_types=1);

namespace Drupal\presigned_url\Signature;

use Drupal\Core\Site\Settings;

/**
 * Generates a signature for a presigned URL.
 */
class PresignedUrlSignatureGenerator {

  public function __construct(
    protected readonly Settings $settings,
  ) {}

  /**
   * Generates a signature for the presigned URL.
   */
  public function generateSignature(string $host, string $uri, string $date, int $expires, string $algorithm): string {
    $privateKey = $this->settings->getHashSalt();

    $signatureString = vsprintf('%s:%s:%s:%s:%s', [
      $host,
      $uri,
      $date,
      $expires,
      $algorithm,
    ]);

    return hash_hmac('sha256', $signatureString, $privateKey);
  }

}
